==> koha-3.00.01.005.tar.gz: koha-3.00.01.005/reviews/reviewswaiting.pl <==
#!/usr/bin/perl

# This file is part of Koha.
#
# Koha is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# Koha is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Koha; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
# Suite 330, Boston, MA  02111-1307 USA

use strict;
use CGI;
use C4::Auth;
use C4::Output;
use C4::Context;
use C4::Review;
use C4::Members;
use C4::Biblio;

my $query = new CGI;
my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
    {
        template_name   => "reviews/reviewswaiting.tmpl",
        query           => $query,
        type            => "intranet",
        authnotrequired => 0,
        flagsrequired   => { tools => 'moderate_comments' },
        debug           => 1,
    }
);

my $op       = $query->param('op');
my $reviewid = $query->param('reviewid');

if ( $op eq 'approve' ) {
    approvereview($reviewid);
}
elsif ( $op eq 'delete' ) {
    deletereview($reviewid);
}

my $reviews = getallreviews(0);

foreach ( @$reviews ) {
    my $borrowernumber = $_->{borrowernumber};
    my $borrowerData   = GetMember($borrowernumber,'borrowernumber');
    my $biblioData     = GetBiblioData($_->{biblionumber});
    # setting some borrower info into this hash
    $_->{bibliotitle} = $biblioData->{'title'};
    $_->{surname}     = $borrowerData->{'surname'};
    $_->{firstname}   = $borrowerData->{'firstname'};
}

$template->param( reviews => $reviews );

output_html_with_http_headers $query, $cookie, $template->output;

==> koha-3.02.05.tar.gz: koha-3.2.5/reviews/reviewswaiting.pl <==
#!/usr/bin/perl

# This file is part of Koha.
#
# Koha is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# Koha is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Koha; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
# Suite 330, Boston, MA  02111-1307 USA

use strict;
use warnings;

use CGI;
use C4::Auth;
use C4::Output;
use C4::Context;
use C4::Review;
use C4::Members;
use C4::Biblio;

my $query = new CGI;
my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
    {
        template_name   => "reviews/reviewswaiting.tmpl",
        query           => $query,
        type            => "intranet",
        authnotrequired => 0,
        flagsrequired   => { tools => 'moderate_comments' },
        debug           => 1,
    }
);

my $op       = $query->param('op') || '';
my $reviewid = $query->param('reviewid');

if ( $op eq 'approve' ) {
    approvereview($reviewid);
}
elsif ( $op eq 'delete' ) {
    deletereview($reviewid);
}

my $reviews = getallreviews(0);

foreach ( @$reviews ) {
    my $borrowernumber = $_->{borrowernumber};
    my $borrowerData   = GetMember('borrowernumber' => $borrowernumber);
    my $biblioData     = GetBiblioData($_->{biblionumber});
    # setting some borrower info into this hash
    $_->{bibliotitle} = $biblioData->{'title'};
    $_->{surname}     = $borrowerData->{'surname'};
    $_->{firstname}   = $borrowerData->{'firstname'};
}

$template->param( reviews => $reviews );

output_html_with_http_headers $query, $cookie, $template->output;
